Learn R Programming

awspack (version 0.1.6)

awspack-package: Amazon Web Services Bundle Package

Description

A simple bundler of the cloudyr project suite of packages for Amazon Web Services (AWS). It imports all functions from all of the AWS packages into its own namespace and exports them. If you only want functions from a specific package, load the individual package instead.

Arguments